==> techutils-0.6.0%2B1.21.10-sources.jar: dev/kikugie/techutils/util/ValidBox.java <==
package dev.kikugie.techutils.util;

import fi.dy.masa.litematica.selection.Box;
import org.apache.commons.lang3.Validate;
import org.jetbrains.annotations.NotNull;

import java.util.Objects;
import net.minecraft.class_2338;

/**
 * An extension of {@link Box} that ensures corners are not null (to shut up the IDE). As well as provides a few utility methods I need.
 */
@SuppressWarnings("NullableProblems")
public class ValidBox extends Box {
	private class_2338 minPos;
	private class_2338 maxPos;

	public ValidBox(class_2338 pos1, class_2338 pos2) {
		super(pos1, pos2, "");
		Objects.requireNonNull(pos1);
		Objects.requireNonNull(pos2);
	}

	public ValidBox(class_2338 pos1, class_2338 pos2, String name) {
		super(pos1, pos2, name);
		Objects.requireNonNull(pos1);
		Objects.requireNonNull(pos2);
	}

	public ValidBox(int[] corners) {
		super(new class_2338(corners[0], corners[1], corners[2]), new class_2338(corners[3], corners[4], corners[5]), "");
	}

	public static ValidBox of(Box box) {
		return new ValidBox(box.getPos1(), box.getPos2(), box.getName());
	}

	@NotNull
	@Override
	public class_2338 getPos1() {
		return Objects.requireNonNull(super.getPos1());
	}

	@Override
	public void setPos1(@NotNull class_2338 pos) {
		super.setPos1(pos);
		updateCorners();
	}

	@NotNull
	@Override
	public class_2338 getPos2() {
		return Objects.requireNonNull(super.getPos2());
	}

	@Override
	public void setPos2(@NotNull class_2338 pos) {
		super.setPos2(pos);
		updateCorners();
	}

	public boolean contains(class_2338 pos) {
		class_2338 min = getMin();
		class_2338 max = getMax();
		return pos.method_10263() >= min.method_10263() && pos.method_10263() <= max.method_10263() &&
			pos.method_10264() >= min.method_10264() && pos.method_10264() <= max.method_10264() &&
			pos.method_10260() >= min.method_10260() && pos.method_10260() <= max.method_10260();
	}

	public boolean equals(Box other) {
		if (other == this)
			return true;
		if (other == null)
			return false;
		if (other.getPos1() == null || other.getPos2() == null)
			return false;
		return getPos1().equals(other.getPos1()) && getPos2().equals(other.getPos2());
	}

	public class_2338 getPos1(class_2338 fallback) {
		class_2338 pos = super.getPos1();
		return pos != null ? pos : fallback;
	}

	public class_2338 getPos2(class_2338 fallback) {
		class_2338 pos = super.getPos2();
		return pos != null ? pos : fallback;
	}

	public class_2338 getMin() {
		if (this.minPos == null)
			updateCorners();
		return this.minPos;
	}

	public class_2338 getMax() {
		if (this.maxPos == null)
			updateCorners();
		return this.maxPos;
	}

	private void updateCorners() {
		class_2338 pos1 = getPos1(class_2338.field_10980);
		class_2338 pos2 = getPos2(class_2338.field_10980);

		int x1 = pos1.method_10263();
		int y1 = pos1.method_10264();
		int z1 = pos1.method_10260();
		int x2 = pos2.method_10263();
		int y2 = pos2.method_10264();
		int z2 = pos2.method_10260();

		int minX = Math.min(x1, x2);
		int minY = Math.min(y1, y2);
		int minZ = Math.min(z1, z2);
		int maxX = Math.max(x1, x2);
		int maxY = Math.max(y1, y2);
		int maxZ = Math.max(z1, z2);

		this.minPos = new class_2338(minX, minY, minZ);
		this.maxPos = new class_2338(maxX, maxY, maxZ);
	}
}

==> techutils-0.6.1%2B1.21.4-sources.jar: dev/kikugie/techutils/util/ValidBox.java <==
package dev.kikugie.techutils.util;

import fi.dy.masa.litematica.selection.Box;
import org.apache.commons.lang3.Validate;
import org.jetbrains.annotations.NotNull;

import java.util.Objects;
import net.minecraft.class_2338;

/**
 * An extension of {@link Box} that ensures corners are not null (to shut up the IDE). As well as provides a few utility methods I need.
 */
@SuppressWarnings("NullableProblems")
public class ValidBox extends Box {
	private class_2338 minPos;
	private class_2338 maxPos;

	public ValidBox(class_2338 pos1, class_2338 pos2) {
		super(pos1, pos2, "");
		Validate.notNull(pos1);
		Validate.notNull(pos2);
	}

	public ValidBox(class_2338 pos1, class_2338 pos2, String name) {
		super(pos1, pos2, name);
		Validate.notNull(pos1);
		Validate.notNull(pos2);
	}

	public ValidBox(int[] corners) {
		super(new class_2338(corners[0], corners[1], corners[2]), new class_2338(corners[3], corners[4], corners[5]), "");
	}

	public static ValidBox of(Box box) {
		return new ValidBox(box.getPos1(), box.getPos2(), box.getName());
	}

	@NotNull
	@Override
	public class_2338 getPos1() {
		return Objects.requireNonNull(super.getPos1());
	}

	@Override
	public void setPos1(@NotNull class_2338 pos) {
		super.setPos1(pos);
		updateCorners();
	}

	@NotNull
	@Override
	public class_2338 getPos2() {
		return Objects.requireNonNull(super.getPos2());
	}

	@Override
	public void setPos2(@NotNull class_2338 pos) {
		super.setPos2(pos);
		updateCorners();
	}

	public boolean contains(class_2338 pos) {
		class_2338 min = getMin();
		class_2338 max = getMax();
		return pos.method_10263() >= min.method_10263() && pos.method_10263() <= max.method_10263() &&
			pos.method_10264() >= min.method_10264() && pos.method_10264() <= max.method_10264() &&
			pos.method_10260() >= min.method_10260() && pos.method_10260() <= max.method_10260();
	}

	public boolean equals(Box other) {
		if (other == this)
			return true;
		if (other == null)
			return false;
		if (other.getPos1() == null || other.getPos2() == null)
			return false;
		return getPos1().equals(other.getPos1()) && getPos2().equals(other.getPos2());
	}

	public class_2338 getPos1(class_2338 fallback) {
		class_2338 pos = super.getPos1();
		return pos != null ? pos : fallback;
	}

	public class_2338 getPos2(class_2338 fallback) {
		class_2338 pos = super.getPos2();
		return pos != null ? pos : fallback;
	}

	public class_2338 getMin() {
		if (this.minPos == null)
			updateCorners();
		return this.minPos;
	}

	public class_2338 getMax() {
		if (this.maxPos == null)
			updateCorners();
		return this.maxPos;
	}

	private void updateCorners() {
		class_2338 pos1 = getPos1(class_2338.field_10980);
		class_2338 pos2 = getPos2(class_2338.field_10980);

		int x1 = pos1.method_10263();
		int y1 = pos1.method_10264();
		int z1 = pos1.method_10260();
		int x2 = pos2.method_10263();
		int y2 = pos2.method_10264();
		int z2 = pos2.method_10260();

		int minX = Math.min(x1, x2);
		int minY = Math.min(y1, y2);
		int minZ = Math.min(z1, z2);
		int maxX = Math.max(x1, x2);
		int maxY = Math.max(y1, y2);
		int maxZ = Math.max(z1, z2);

		this.minPos = new class_2338(minX, minY, minZ);
		this.maxPos = new class_2338(maxX, maxY, maxZ);
	}
}
